Struct amazon_sp_services::models::technician::Technician
source · [−]Expand description
Technician : A technician who is assigned to perform the service job in part or in full.
Fields
technician_id: Option<String>The technician identifier.
name: Option<String>The name of the technician.
Implementations
sourceimpl Technician
impl Technician
sourcepub fn new() -> Technician
pub fn new() -> Technician
A technician who is assigned to perform the service job in part or in full.